.. Copyright 2013-2023 Reahl Software Services (Pty) Ltd. All rights reserved.

Module reahl.domainui.bootstrap.workflow
----------------------------------------

.. automodule:: reahl.domainui.bootstrap.workflow


InboxUI
"""""""

.. autoclass:: InboxUI
   :members:

TaskWidget
""""""""""

.. autoclass:: TaskWidget
   :members:
